import { SequentialEvent } from './sequential-event';
import { IEventHandler, IOnceHandler, IEventHash, IEventsHash } from './interfaces';
/**
 * Handle execution of all handlers in sequence.
 *
 * @memberof SequentialEvent
 * @author Gerkin
 * @inner
 */
export declare const emitHandlers: (handlers: IEventHandler | IEventHandler[], object: SequentialEvent, args: any[]) => Promise<any>;
/**
 * Generate next promise for sequence.
 *
 * @memberof SequentialEvent
 * @author Gerkin
 * @inner
 */
export declare const getNextPromise: (handlers: IEventHandler[], object: SequentialEvent, args: any[]) => (resolve: Function, reject: (reason: any) => any) => Function;
/**
 * Generate an event handler that deregister itself when executed. This handler will be executed  just once.
 *
 * @param   target    - Event emitter that will use the handler.
 * @param   eventName - Name of the event to trigger.
 * @param   eventFn   - Handler for the event.
 * @returns Function that will be executed only once.
 * @memberof SequentialEvent
 * @author Gerkin
 * @inner
 */
export declare const onceify: (target: SequentialEvent, eventName: string, eventFn: IEventHandler) => IOnceHandler;
/**
 * Remove provided `callback` from listeners of event `eventCat`.
 *
 * @memberof SequentialEvent
 * @author Gerkin
 * @inner
 */
export declare const removeEventListener: (eventCat: IEventHandler[], callback: IEventHandler[]) => void;
/**
 * Add an event listener to the provided event hash.
 *
 * @memberof SequentialEvent
 * @author Gerkin
 * @inner
 */
export declare const addEventListener: (eventHash: IEventsHash, eventName: string, callback: IEventHandler[]) => void;
/**
 * Ensure that event & callback are on the associative hash format.
 *
 * @memberof SequentialEvent
 * @author Gerkin
 * @inner
 */
export declare const ensureArray: <T>(data: T | T[]) => T[];
export declare const forEachObj: <T>(object: {
    [key: string]: T;
}, callback: (value: T, key: string) => any) => void;
export declare const castArgsToEventsHash: (events: string | IEventHash, callback?: IEventHandler | IEventHandler[] | undefined) => IEventsHash;
